@@ -143,7 +143,7 @@ cgr_control_limit <- function(time, alpha = 0.05, psi, n_sim = 20, coxphmod,
   #2. Construct the CGR-CUSUM chart for each hospital until timepoint time
   #3. Determine control limit h such that at most proportion alpha of the
   #   instances will produce a signal.
-
+  unit <- NULL
   set.seed(seed)
   manualcbaseh <- FALSE
 
@@ -153,6 +153,27 @@ cgr_control_limit <- function(time, alpha = 0.05, psi, n_sim = 20, coxphmod,
   call = match.call()
 
 
+  #Time must be positive and numeric
+  if(!all(is.numeric(time), length(time) == 1, time > 0)){
+    stop("Argument time must be a single positive numeric value.")
+  }
+
+  #alpha must be between 0 and 1
+  if(!all(is.numeric(alpha), length(alpha) == 1, alpha > 0, alpha < 1)){
+    stop("Argument alpha must be a single numeric value between 0 and 1.")
+  }
+
+  #Check that psi is a numeric value greater than 0
+  if(!all(is.numeric(psi), length(psi) == 1, psi > 0)){
+    stop("Argument psi must be a single numeric value larger than 0.")
+  }
+
+  #Check that n_sim is a numeric value greater than 0
+  if(!all(n_sim%%1 == 0, length(n_sim) == 1, n_sim > 0)){
+    stop("Argument n_sim must be a single integer value larger than 0.")
+  }
+
+
   #First we generate the n_sim unit data
   if(pb){ message("Step 1/3: Generating in-control data.")}
   df_temp <- generate_units(time = time, psi = psi, n_sim = n_sim, cbaseh = cbaseh,
